-------------------------------------------------------------------------------
-- MrTrader 
--
-- Suite of tools for the avid crafter.
--
-- Send suggestions, comments, and bugs to user@zedonline.net
-------------------------------------------------------------------------------

local L = LibStub("AceLocale-3.0"):GetLocale("MrTrader", true);

-----
-- MRTSkillUps - Plugin to provide a badge for skill ups
--
-- Interfaces -
--   TradeSkillWindowInfoBadge - Provides a badge for the skill.
-----
MRTSkillUps = {
	id = "263178d0-dc0f-4748-9aea-0ac5a1195881",
	name = L["Skill Ups"],
	interfaces = {
		TradeSkillWindowInfoBadge = function(tradeskillInfo) return MRTSkillUps:TradeSkillWindowInfoBadge(tradeskillInfo) end,
 	}
};
MRTAPI:RegisterPlugin(MRTSkillUps)

function MRTSkillUps:TradeSkillWindowInfoBadge(tradeskillInfo)
	if( tradeskillInfo.numSkillUps ~= nil ) then
		if( tradeskillInfo.numSkillUps > 1 and tradeskillInfo.skillType=="optimal" ) then
			return "Interface\\TradeSkillFrame\\UI-TradeSkill-Multiskill", tradeskillInfo.numSkillUps, "Skill Ups", nil;
		end
	end
	
	return nil;
end

function MRTSkillUps:BadgeWasClicked(tradeskillIndex)
	print(GetTradeSkillInfo(tradeskillIndex));
end

-----
-- MRTToolsAndCooldown - Plugin to provide cooldown and tool information for skills in a single line
--
-- Interfaces:
--   TradeSkillWindowInfoLine - Provides a line of info text for a recipe
-----
MRTToolsAndCooldown = {
    id = "50ad4feb-60bd-447b-abfe-be5fbbf2c189",
    name = L["Tools and Cooldown"],
    interfaces = {
        TradeSkillWindowInfoLine = function(tradeskillInfo) return MRTToolsAndCooldown:TradeSkillWindowInfoLine(tradeskillInfo) end,
    },
};
MRTAPI:RegisterPlugin(MRTToolsAndCooldown);

function MRTToolsAndCooldown:TradeSkillWindowInfoLine(tradeskillInfo)
	local result = nil;

	if( tradeskillInfo.skillCooldown ~= nil ) then
		result = "|cffff0000" .. COOLDOWN_REMAINING .. " " .. SecondsToTime(tradeskillInfo.skillCooldown) .. "|r";
	end
	if( tradeskillInfo.skillCooldown == nil and tradeskillInfo.skillTools ~= nil and getn(tradeskillInfo.skillTools) > 0 ) then
		result = MRTToolsAndCooldown:BuildToolString(tradeskillInfo.skillTools);
	end
	
	return result;
end

function MRTToolsAndCooldown:BuildToolString(table)
	local result = "";

	local count = getn(table);
	for i=1,count,2 do
		local k = table[i];
		local v = table[i+1];
		if( result ~= "" ) then result = result .. ", " end;
		_, _, _, _, _, _, _, _, _, texture = GetItemInfo(k);
		
		if(texture) then
			result = result .. "|T" .. texture .. ":12:12:2:0|t "
		end
		
		if( v ~= 1 ) then
			result = result .. "|cffff0000" .. k .. "|r";
		else
			result = result .. k;
		end
	end
	
	if( result ~= "" ) then
		result = REQUIRES_LABEL .. " " .. result;
		return result;
	end
	
	return nil;
end